<?php

namespace Drupal\ds_test\Plugin\Block;

use Drupal\Core\Block\BlockBase;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
use Symfony\Component\HttpFoundation\RequestStack;

/**
 * Defines a Display suite cache test block.
 *
 * @Block(
 *   id = "ds_cache_test_block",
 *   admin_label = @Translation("Display Suite Cache Test Block"),
 *   category = @Translation("ds")
 * )
 */
class DsCacheTestBlock extends BlockBase implements ContainerFactoryPluginInterface {

  /**
   * Request stack that controls the lifecycle of requests.
   *
   * @var \Symfony\Component\HttpFoundation\RequestStack
   */
  protected $stack;

  /**
   * Constructs a \Drupal\ds_test\Plugin\Block\DsTestBloc object.
   *
   * @param array $configuration
   *   A configuration array containing information about the plugin instance.
   * @param string $plugin_id
   *   The plugin_id for the plugin instance.
   * @param mixed $plugin_definition
   *   The plugin implementation definition.
   * @param \Symfony\Component\HttpFoundation\RequestStack $stack
   *   Request stack that controls the lifecycle of requests.
   */
  public function __construct(array $configuration, $plugin_id, $plugin_definition, RequestStack $stack) {
    parent::__construct($configuration, $plugin_id, $plugin_definition);
    $this->stack = $stack;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    return new static(
      $configuration,
      $plugin_id,
      $plugin_definition,
      $container->get('request_stack')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function build() {
    /** @var \Symfony\Component\HttpFoundation\Request $request */
    $request = $this->stack->getCurrentRequest();

    return [
      // Print the entire query string.
      '#markup' => $request->getQueryString(),
      '#cache' => [
        'contexts' => ['timezone', 'user'],
        'max-age' => 20,
      ],
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function getCacheContexts() {
    return ['url.path', 'url.query_args'];
  }

  /**
   * {@inheritdoc}
   */
  public function getCacheTags() {
  }

  /**
   * {@inheritdoc}
   */
  public function getCacheMaxAge() {
    return 30;
  }

}
