<?php

namespace Drupal\ds_test\Plugin\Block;

use Drupal\Core\Access\AccessResult;
use Drupal\Core\Session\AccountInterface;
use Drupal\Core\Block\BlockBase;
use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
use Drupal\Core\State\StateInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Defines a Display suite test block.
 *
 * @Block(
 *   id = "ds_test_block",
 *   admin_label = @Translation("Display Suite Test Block"),
 *   category = @Translation("ds")
 * )
 */
class DsTestBlock extends BlockBase implements ContainerFactoryPluginInterface {

  /**
   * The state storage service.
   *
   * @var \Drupal\Core\State\StateInterface
   */
  protected $state;

  /**
   * Constructs a \Drupal\ds_test\Plugin\Block\DsTestBloc object.
   *
   * @param array $configuration
   *   A configuration array containing information about the plugin instance.
   * @param string $plugin_id
   *   The plugin_id for the plugin instance.
   * @param mixed $plugin_definition
   *   The plugin implementation definition.
   * @param \Drupal\Core\State\StateInterface $state
   *   The state storage service.
   */
  public function __construct(array $configuration, $plugin_id, $plugin_definition, StateInterface $state) {
    parent::__construct($configuration, $plugin_id, $plugin_definition);
    $this->state = $state;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    return new static(
      $configuration,
      $plugin_id,
      $plugin_definition,
      $container->get('state')
    );
  }

  const BODY_TEXT = 'Display suite test block.';

  /**
   * {@inheritdoc}
   */
  protected function blockAccess(AccountInterface $account) {
    return AccessResult::allowedIf($this->state->get('ds_test_block__access', FALSE));
  }

  /**
   * {@inheritdoc}
   */
  public function build() {
    $build = [];
    $build[]['#markup'] = $this::BODY_TEXT;
    return $build;
  }

  /**
   * Ensure that this object is not cached.
   */
  public function getCacheMaxAge() {
    return 0;
  }

}
